@@ -518,8 +518,74 @@ static void vo2s_L(unsigned char * ansp, const int o,
   }
 }
 
+static void vor2_SeqS1(unsigned char * ansp, const SEXP * xp, R_xlen_t N, const char * y, const int ny) {
+  for (R_xlen_t i = 0; i < N; ++i) {
+    if (ansp[i]) {
+      continue;
+    }
+    int nxi = length(xp[i]);
+    if (nxi != ny) {
+      continue;
+    }
+    const char * xi = CHAR(xp[i]);
+    ansp[i] = string_equal(xi, y);
+  }
+}
+
+static void vor2_SneqS1(unsigned char * ansp, const SEXP * xp, R_xlen_t N, const char * y, const int ny) {
+  for (R_xlen_t i = 0; i < N; ++i) {
+    if (ansp[i]) {
+      continue;
+    }
+    int nxi = length(xp[i]);
+    if (nxi != ny) {
+      ansp[i] = 1;
+      continue;
+    }
+    const char * xi = CHAR(xp[i]);
+    ansp[i] = !string_equal(xi, y);
+  }
+}
+
+static void vor2_SeqS(unsigned char * ansp, const SEXP * xp, R_xlen_t N, const SEXP * yp) {
+  for (R_xlen_t i = 0; i < N; ++i) {
+    if (ansp[i]) {
+      continue;
+    }
+    ansp[i] = string_equal(CHAR(xp[i]), CHAR(yp[i]));
+  }
+}
+
+static void vor2_SneqS(unsigned char * ansp, const SEXP * xp, R_xlen_t N, const SEXP * yp) {
+  for (R_xlen_t i = 0; i < N; ++i) {
+    if (ansp[i]) {
+      continue;
+    }
+    ansp[i] = !string_equal(CHAR(xp[i]), CHAR(yp[i]));
+  }
+}
+
+static void vor2_SS(unsigned char * ansp, const int o,
+                     const SEXP * x, R_xlen_t N,
+                     const SEXP * y, R_xlen_t M) {
+  if (M == 1) {
+    if (o == OP_EQ) {
+      vor2_SeqS1(ansp, x, N, CHAR(y[0]), length(y[0]));
+    } else {
+      vor2_SneqS1(ansp, x, N, CHAR(y[0]), length(y[0]));
+    }
+  } else {
+    if (o == OP_EQ) {
+      vor2_SeqS(ansp, x, N, y);
+    } else {
+      vor2_SneqS(ansp, x, N, y);
+    }
+  }
+}
+
 static void vor2s(unsigned char * ansp, const int o,
-                  SEXP x, SEXP y, int nThread) {
+                  SEXP x, SEXP y, int nThread,
+                  int * err) {
   R_xlen_t N = xlength(x);
   R_xlen_t M = xlength(y);
 
@@ -541,6 +607,8 @@ static void vor2s(unsigned char * ansp, const int o,
     case REALSXP:
       vor2s_ID(ansp, o, INTEGER(x), N, REAL(y), M, nThread);
       break;
+    default:
+      *err = OR3__UNSUPPORTED_TYPEY;
     }
     break;
   case REALSXP:
@@ -551,8 +619,20 @@ static void vor2s(unsigned char * ansp, const int o,
     case REALSXP:
       vor2s_DD(ansp, o, REAL(x), N, REAL(y), M, nThread);
       break;
+    default:
+      *err = OR3__UNSUPPORTED_TYPEY;
     }
     break;
+  case STRSXP:
+    if (TYPEOF(y) == STRSXP && (o == OP_EQ || o == OP_NE)) {
+      // only support == and !=
+      vor2_SS(ansp, o, STRING_PTR(x), N, STRING_PTR(y), M);
+    } else {
+      *err = OR3__UNSUPPORTED_TYPEY;
+    }
+    break;
+  default:
+    *err = OR3__UNSUPPORTED_TYPEX;
   }
 }
 
@@ -574,6 +654,7 @@ SEXP Cors(SEXP oo1, SEXP xx1, SEXP yy1,
   const int o2 = sex2op(oo2);
   SEXP ans = PROTECT(allocVector(RAWSXP, N));
   unsigned char * ansp = RAW(ans);
+  int err[1] = {0};
 
   if (yy1 == R_NilValue && isLogical(xx1)) {
     const int * xx1p = LOGICAL(xx1);
@@ -590,12 +671,16 @@ SEXP Cors(SEXP oo1, SEXP xx1, SEXP yy1,
     FORLOOP(
       ansp[i] = 0;
     )
-    vor2s(ansp, o1, xx1, yy1, nThread);
+    vor2s(ansp, o1, xx1, yy1, nThread, err);
   }
   if (use2) {
-    vor2s(ansp, o2, xx2, yy2, nThread);
+    vor2s(ansp, o2, xx2, yy2, nThread, err);
   }
   UNPROTECT(1);
+  if (err[0]) {
+    REprintf("Unsupported type");
+    return R_NilValue;
+  }
   return ans;
 }
 
